stdlib

package
v0.0.0-...-0bea74a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 17, 2025 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

const DateLib = `` /* 1992-byte string literal not displayed */

DateLib contains the source code for the date standard library

const HTTPLib = `` /* 1519-byte string literal not displayed */

HTTPLib contains the source code for the HTTP standard library

const TimeLib = `` /* 1086-byte string literal not displayed */

TimeLib contains the source code for the time standard library

Variables

var RegisteredLibs = []Library{
	{Name: "date", Content: DateLib},
	{Name: "http", Content: HTTPLib},
	{Name: "time", Content: TimeLib},
}
var StdLibFiles = initStdLibFiles()

Functions

func AutoRegisterLibrariesFromDir

func AutoRegisterLibrariesFromDir(dirPath string) error

func AutoRegisterLibraryFromFile

func AutoRegisterLibraryFromFile(path string) error

func RegisterLibrary

func RegisterLibrary(name string, content string)

Types

type Library

type Library struct {
	Name    string
	Content string
}

Jump to