Documentation
¶
Index ¶
Constants ¶
const DateLib = `` /* 1992-byte string literal not displayed */
DateLib contains the source code for the date standard library
const HTTPLib = `` /* 1519-byte string literal not displayed */
HTTPLib contains the source code for the HTTP standard library
const TimeLib = `` /* 1086-byte string literal not displayed */
TimeLib contains the source code for the time standard library
Variables ¶
var RegisteredLibs = []Library{ {Name: "date", Content: DateLib}, {Name: "http", Content: HTTPLib}, {Name: "time", Content: TimeLib}, }
var StdLibFiles = initStdLibFiles()
Functions ¶
func RegisterLibrary ¶
Types ¶
Click to show internal directories.
Click to hide internal directories.